@@ -680,7 +680,7 @@ void rejustify(short mode)
       undrawtext(curlabel);
       jsave = curlabel->justify;
       curlabel->justify = transjust[mode] |
-		(curlabel->justify & (FLIPINV | PINVISIBLE));
+		(curlabel->justify & NONJUSTFIELD);
       if (jsave != curlabel->justify) changed = True;
       redrawtext(curlabel);
       UDrawTLine(curlabel);
@@ -695,7 +695,7 @@ void rejustify(short mode)
             jsave = curlabel->justify;
 	    undrawtext(curlabel);
       	    curlabel->justify = transjust[mode] |
-		(curlabel->justify & (FLIPINV | PINVISIBLE));
+		(curlabel->justify & NONJUSTFIELD);
             if (jsave != curlabel->justify) changed = True;
 	    redrawtext(curlabel);
 	 }
