@@ -1214,13 +1214,7 @@ void toggleexcl(xcWidget widget, menuptr menu, int menulength)
 /* Toggle a menu item */
 /*--------------------*/
 
-#ifdef TCL_WRAPPER
-
-void toggle(xcWidget w, Boolean *boolvalue, caddr_t calldata)
-{
-}
-
-#else
+#ifndef TCL_WRAPPER
 
 void toggle(xcWidget w, Boolean *boolvalue, caddr_t calldata)
 {
@@ -2328,27 +2322,25 @@ void setdefaultfontmarks()
 
 void dojustifybit(xcWidget w, labelptr settext, short bitfield)
 {
-   short newjust;
-   Boolean boolval;
-   u_short value;
-
    if (settext != NULL) {
-      boolval = (settext->justify & bitfield) ? True : False;
-      value = boolval ? 0 : bitfield;
-      newjust = (settext->justify & (~bitfield)) | value;
-
       undrawtext(settext);
-      settext->justify = newjust;
+      settext->justify ^= bitfield;
       redrawtext(settext);
       pwriteback(areastruct.topinstance);
    }
-   else {
-      boolval = (areastruct.justify & bitfield) ? True : False;
-      value = boolval ? 0 : bitfield;
-      newjust = (areastruct.justify & (~bitfield)) | value;
-      areastruct.justify = newjust;
+   else
+      areastruct.justify ^= bitfield;
+
+#ifndef TCL_WRAPPER
+   if (w != NULL) {
+      Boolean boolval;
+      if (settext)
+	 boolval = (settext->justify & bitfield) ? 0 : 1;
+      else
+	 boolval = (areastruct.justify & bitfield) ? 0 : 1;
+      toggle(w, &boolval, NULL);
    }
-   if (w != NULL) toggle(w, &boolval, NULL);
+#endif
 }
 
 /*--------------------------------------------------------------*/
@@ -2360,20 +2352,19 @@ void dojustifybit(xcWidget w, labelptr settext, short bitfield)
 
 void dopinjustbit(xcWidget w, labelptr settext, short bitfield)
 {
-   short newjust;
-   Boolean boolval;
-   u_short value;
-
-   if (settext != NULL && settext->pin) {
-      boolval = (settext->justify & bitfield) ? True : False;
-      value = boolval ? 0 : bitfield;
-      newjust = (settext->justify & (~bitfield)) | value;
 
+   if ((settext != NULL) && settext->pin) {
       undrawtext(settext);
-      settext->justify = newjust;
+      settext->justify ^= bitfield;
       redrawtext(settext);
       pwriteback(areastruct.topinstance);
-      if (w != NULL) toggle(w, &boolval, NULL);
+
+#ifndef TCL_WRAPPER
+      if (w != NULL) {
+	 Boolean boolval = (settext->justify & bitfield) ? 0 : 1;
+	 toggle(w, &boolval, NULL);
+      }
+#endif
    }
 }
 
