@@ -293,7 +293,7 @@ menustruct FileMenu[] = {
 	{"Load New Library", action(getuserlib, NULL)},
 	{"Save Library", action(savelibpopup, Number(0))},
 	{" ", noaction},
-        {"Clear Page", action(resetbutton, NULL)},
+        {"Clear Page", action(resetbutton, Number(0))},
 	{" ", noaction},
 	{"Quit", action(quitcheck, NULL)},
 };
