@@ -448,13 +448,11 @@ extern void setfontmarks(short, short);
 extern void startparam(xcWidget, pointertype, caddr_t);
 extern void startunparam(xcWidget, pointertype, caddr_t);
 extern void setdefaultfontmarks();
-extern void dopinvisible(xcWidget, labelptr);
-extern void doflipflip(xcWidget, labelptr);
+extern void setjustbit(xcWidget, pointertype, caddr_t);
+extern void setpinjustbit(xcWidget, pointertype, caddr_t);
 extern void setjust(xcWidget, pointertype, labelptr, short);
 extern void setvjust(xcWidget, pointertype, caddr_t);
 extern void sethjust(xcWidget, pointertype, caddr_t);
-extern void setflipinv(xcWidget, pointertype, caddr_t);
-extern void setpinvisible(xcWidget, pointertype, caddr_t);
 extern void boxedit(xcWidget, pointertype, caddr_t);
 extern void locloadfont(xcWidget, char *);
 extern void addnewfont(xcWidget, caddr_t, caddr_t);
